"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getMatchedRule = getMatchedRule;
exports.parseFile = parseFile;
var _logger = require("@linaria/logger");
var _utils = require("@linaria/utils");
var _loadLinariaOptions = _interopRequireDefault(require("./loadLinariaOptions"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function getMatchedRule(rules, filename, code) {
  for (let i = rules.length - 1; i >= 0; i--) {
    const rule = rules[i];
    if (!rule.test) {
      return rule;
    }
    if (typeof rule.test === 'function' && rule.test(filename, code)) {
      return rule;
    }
    if (rule.test instanceof RegExp && rule.test.test(filename)) {
      return rule;
    }
  }
  return {
    action: 'ignore'
  };
}
function parseFile(babel, filename, originalCode, options) {
  const log = (0, _logger.createCustomDebug)('transform:parse', (0, _utils.getFileIdx)(filename));
  const pluginOptions = (0, _loadLinariaOptions.default)(options.pluginOptions);
  const {
    action,
    babelOptions
  } = getMatchedRule(pluginOptions.rules, filename, originalCode);
  if (action === 'ignore' || filename.endsWith('.json')) {
    log('stage-1', `${filename} has been ignored because of ${action === 'ignore' ? 'rule' : 'extension'}`);
    return ['ignored', originalCode];
  }
  const parseConfig = (0, _utils.buildOptions)(pluginOptions === null || pluginOptions === void 0 ? void 0 : pluginOptions.babelOptions, babelOptions);
  const parseResult = babel.parseSync(originalCode, {
    ...parseConfig,
    sourceMaps: true,
    sourceFileName: filename,
    inputSourceMap: options.inputSourceMap,
    root: options.root,
    ast: true,
    filename
  });
  if (!parseResult) {
    throw new Error(`Failed to parse ${filename}`);
  }
  log('stage-1', `${filename} has been parsed`);
  return [parseResult, originalCode];
}
//# sourceMappingURL=parseFile.js.map